@@ -35,3 +35,19 @@ imap <- function(.x, .f, ...) {
 
 seq_nrow <- function(x) seq_len(nrow(x))
 seq_ncol <- function(x) seq_len(ncol(x))
+
+# Until https://github.com/r-lib/rlang/issues/675 is fixed
+ensym2 <- function(arg) {
+  arg <- ensym(arg)
+
+  expr <- eval_bare(expr(enquo(!!arg)), caller_env())
+  expr <- quo_get_expr(expr)
+
+  if (is_string(expr)) {
+    sym(expr)
+  } else if (is_symbol(expr)) {
+    expr
+  } else {
+    abort("Must supply a symbol or a string as argument")
+  }
+}
